@@ -12,6 +12,8 @@ __email__ = 'vmalloc@gmail.com'
 _MARKER = 'GDGT::'
 
 TYPE_CODES = munch.Munch(
+    CREATE='CR',
+    DELETE='DL',
     OPERATION='OP',
     STATE='ST',
     UPDATE='UP',
@@ -37,6 +39,23 @@ class Setup(object):
 
 _setups = [Setup()]
 
+def log_entity_creation(entity, params=None):
+    """Logs an entity creation
+    """
+    p = {'entity': entity}
+    if params:
+        p['params'] = params
+    _log(TYPE_CODES.CREATE, p)
+
+
+def log_entity_deletion(entity, params=None):
+    """Logs an entity creation
+    """
+    p = {'entity': entity}
+    if params:
+        p['params'] = params
+    _log(TYPE_CODES.DELETE, p)
+
 
 def log_operation(entities, operation_name, params=None):
     """Logs an operation done on an entity, possibly with other arguments
@@ -113,6 +132,6 @@ def parse_log_line(line):
     elif returned.type == TYPE_CODES.UPDATE:
         returned.entity = returned.params.get('on')
         returned.update = returned.params.get('update')
-    elif returned.type == TYPE_CODES.ERROR:
-        returned.params = returned.params
+    elif returned.type in [TYPE_CODES.CREATE, TYPE_CODES.DELETE]:
+        returned.entity = returned.params.get('entity')
     return returned
